%global newname htcondor
%global srcver 8_3_5

Name:           condor
Version:        8.3.5
Release:        1%{?dist}
Summary:        High Throughput Computing

License:        ASL 2.0
URL:            http://research.cs.wisc.edu/htcondor
Source0:        https://github.com/htcondor/htcondor/archive/V%{srcver}/%{newname}-%{srcver}.tar.gz
# https://github.com/htcondor/htcondor/pull/8, 5d3a6ed
Patch1:         condor-classad-autotools-update.patch
# https://github.com/htcondor/htcondor/pull/8, 8764620
Patch2:         condor-classad-obsolete-macros.patch
# https://github.com/htcondor/htcondor/pull/8, 40afe43
Patch3:         condor-classad-unittests.patch

BuildRequires:  autoconf
BuildRequires:  boost-devel
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  pcre-devel

%description
HTCondor is a workload management system for high-throughput and
high-performance jobs. Like other full-featured batch systems, HTCondor
provides a job queuing mechanism, scheduling policy, priority scheme,
resource monitoring, and resource management. Users submit their
serial or parallel jobs to HTCondor, HTCondor places them into a queue,
chooses when and where to run the jobs based upon a policy, carefully
monitors their progress, and ultimately informs the user upon
completion.


%package classads
Summary:        HTCondor's classified advertisement language
Obsoletes:      classads < 1.0.9
Provides:       classads = %{version}-%{release}

%description classads
Classified Advertisements (classads) are the lingua franca of
HTCondor. They are used for describing jobs, workstations, and other
resources. They are exchanged by HTCondor processes to schedule
jobs. They are logged to files for statistical and debugging
purposes. They are used to enquire about current state of the system.

A classad is a mapping from attribute names to expressions. In the
simplest cases, the expressions are simple constants (integer,
floating point, or string). A classad is thus a form of property
list. Attribute expressions can also be more complicated. There is a
protocol for evaluating an attribute expression of a classad vis a vis
another ad. For example, the expression "other.size > 3" in one ad
evaluates to true if the other ad has an attribute named size and the
value of that attribute is (or evaluates to) an integer greater than
three. Two classads match if each ad has an attribute requirements
that evaluates to true in the context of the other ad. Classad
matching is used by the HTCondor central manager to determine the
compatibility of jobs and workstations where they may be run.


%package classads-devel
Summary:        Headers for HTCondor's classified advertisement language
Requires:       %name-classads%{_isa} = %version-%release
Requires:       pcre-devel%{_isa}
Obsoletes:      classads-devel < 1.0.9
Provides:       classads-devel = %{version}-%{release}

%description classads-devel
Header files for HTCondor's ClassAd Library, a powerful and flexible,
semi-structured representation of data.


%prep
%setup -q -n %{newname}-%{srcver}
%patch1 -p1
%patch2 -p1
%patch3 -p1


%build
pushd src/classad
m4 Makefile.am.m4 > Makefile.am
autoreconf --force --install
%configure --disable-static
mkdir classad || :
sed classad/classad_stl.h.in \
  -e 's/^#cmakedefine \(PREFER_CPP11\)/#define \1 1/' \
  -e 's/^#cmakedefine \(PREFER_TR1\)/\/* #undef \1 *\//' \
  > classad/classad_stl.h
make %{?_smp_mflags}


%check
pushd src/classad
make check


%install
pushd src/classad
make install DESTDIR=%{buildroot}


%post classads -p /sbin/ldconfig

%postun classads -p /sbin/ldconfig


%files

%files classads
%doc NOTICE.txt
%license LICENSE-2.0.txt
%{_bindir}/classad_functional_tester
%{_bindir}/classad_version
%{_bindir}/cxi
%{_libdir}/libclassad.so.7
%{_libdir}/libclassad.so.7.*

%files classads-devel
%{_includedir}/classad/
%{_libdir}/libclassad.so
%exclude %{_libdir}/libclassad.la


%changelog
* Wed Apr 29 2015 František Dvořák <valtri@civ.zcu.cz> - 8.3.5-1
- Initial package
